from setuptools import setup, find_packages

setup(
    name="kfsd",
    version="0.0.218",
    description="Sample App",
    long_description="Sample Pkg",
    long_description_content_type="text/markdown",
    author="Gokul Nathan",
    author_email="nathangokul111@gmail.com",
    packages=find_packages(),
    include_package_data=True,
    install_requires=[],
)
